---
title: "Introduction"
type: Chapter
slug: true
front: false
---
>> The real long-term future of computing consists of figuring out how to make the best possible use we can out of the literal millions of devices which already exist.

<cite>(Solderpunk, 2020, Cited in de Valk, 2022)</cite>

Beware! If you’ve picked up this publication expecting to learn how to make a flawless, DAWless, in tune and always working polysynth, think again. However, if you, like me, are interested in making screamy, dreamy, noise boxes using an alternative resource: trash, you’ve come to the right place.

When I first read about salvage computing, I got very excited. Being part of the DIY Sound community, I’ve developed a growing discomfort with some aspects of the practice. Over the past few years, I’ve hosted workshops around circuit bending[^circuit-bending] and LOFI sound devices in and around Rotterdam. These workshops are meant as an accessible way to get people tinkering with electronics, through something infinitely playful: making instruments[^playful].

[^circuit-bending]: the practice around hacking discarded toys to find sonic potential through creating shorts, or sometimes literally bending the circuit.

[^playful]: Making instruments is a great way to learn about and work with the *flow* of electricity

In an ecosystem where a printer is only printing with a costly subscription [^printer-subscription], disruptive products become obsolete within a year[^AI-pin], fixing flat tires is outsourced [^swapfiets] and some smartphones literally have to be frozen [^frozen] to be able to replace the battery, it’s clear we’re no longer in charge of our own devices. Warranty-void stickers and lengthy terms and conditions scare us into compliance. I’ve noticed how empowering these first-time soldering workshops can be in taking back this autonomy by making (or breaking) a circuit together. They are a shared attempt to uncover some of the black boxes in our own products[@hertzZombieMediaCircuit2012]. However, the toys and materials used in the workshops are single-use [^single-use] and, with ease, thrown out afterward. The carelessness notion creeps in that waste has no value, and is easily replaceable, and broke my heart a bit, one workshop at a time.

[^printer-subscription]: HP’s “all-inclusive” printers can only be used with an active subscription [@editorNightmareRealHP]

[^AI-pin]: Humane Inc. Ai Pin closed their servers within one year after releasing their “Ai Pin”. Now, you can only ask this piece of hardware how many batteries it has left. [@chokkattuWhatYourDefunct2025]

[^swapfiets]: [Swapfiets](https://swapfiets.nl/service#support) promote their bike subscriptions as “We give you a bike that you never have to repair”

[^frozen]: The Nothing Phone scored a 1/10 in iFixit's repairability score [@EssentialPhoneTeardown2017]

[^single-use]: but often required much preparation in terms of collecting, transporting, repairing, testing, cleaning, prepare.

This is where the field guide comes into play: Can we shift the practice of playful tinkering to acknowledge, rather than ignore, the waste streams they are part of? Limiting ourselves to only use salvaged components and discovering; is it possible to *live off* (create with) electronic components salvaged in the wild? And what would such a practice entail?

[^waste-streams]: on the contrary of neatly prepping everything beforehand and being in charge of the cleaning afterward.

Because salvage is not just about reusing materials; but about confronting the systems that created the waste in the first place. Waste is not only obsolete media but also the by-product of the entire production lifecycle of an electronic product; From the mining of minerals that make up the hardware to the inevitable disposal site [@gabrysSalvage2012]. Since the rate at which waste is collected and recycled isn't growing at the same pace as our collective buying and production, the landfills will continue to grow. Parikka even goes as far to say as that recycling is ultimately "trade-waste", where our abandoned devices are shipped across the ocean  [@parikkaDustMatter2012]



## Beyond the kit
The preference for buying new is noticeable in the DIY synth community as well. When publishing about a project it's common to share a pre-filled webshop cart along with the schematics, or even sell it as a pre-compiled kit[^KIT]. To me, this goes against the ethos of DIY, which is about making do with what you have, with a focus on doing, and not the "thing" [@hertzArtDIYElectronics2023]. Instead, a whole new market is created consisting of Lego-like kits. These kits gloss over the actual challenges and difficulties of creating sound boxes, preventing the development of much-needed problem-solving skills, and not actually discovering anything new [@CooperativeExperimentalismSharing].

[^KIT]: ![Kit from Bastl Instruments](/assets/chapters/bastl_kit.webp)

<ins>Echt foto's maken...</ins>
Instead, what we're building is a starting point. Small electronic circuits that make sound on their own, but you can also duplicate, manipulate, and modulate into something entirely different.

On that note, I am by no means an expert in electronics. When I write about how things work, please take it with a grain of salt. This guide represents my personal understanding, which, no doubt, contains incorrect assumptions or oversimplifications. When in doubt, ask a friend!

The guide is split up into five chapters, each focusing on a different stage of salvaging for sound devices:

#### 1. Gathering hardware
*We'll go through which devices work for salvaging, and where to find them. And talk about dealing with hidden waste streams and obsolescence.*

#### 2. Dismantling devices
Discovery of strategies that manufacturers use to keep you out of their devices

#### 3. Components to salvage
*An overview of parts to salvage, how to identify them, and how to reuse them*

#### 4. Recipes for making
*strategies for making with salvaged parts, and ways to modify the devices.*

#### 5. Taking inventory
*Cleaning up the inventory and looking back*
